==> 0.0.1.tar.gz: android/src/main/java/com/acuant/sampleapp/TruliooVerificationHelper.kt <==
package com.acuant.sampleapp

import com.trulioo.normalizedapi.ApiClient
import com.trulioo.normalizedapi.api.ConnectionApi
import com.trulioo.normalizedapi.api.VerificationsApi

public class TruliooVerificationHelper {
        //Enter Trulioo credentials
        private val username = "IOTPay_Demo_DocV_API1"
        private val password = "Iotpay888666!@#\$"
        private var apiClient:ApiClient? = null

        fun init(){
                apiClient = ApiClient()
                apiClient?.setUsername(username)
                apiClient?.setPassword(password)
                // Set server address
                // GG20
                // apiClient?.setBasePath("https://api.globaldatacompany.com/")
                // GG25
                apiClient?.setBasePath("https://api.globaldatacompany.com/")
        }

        fun getConnectionClient():ConnectionApi{
                if(apiClient != null)
                {
                        return ConnectionApi(apiClient)
                }
                return ConnectionApi(ApiClient())
        }

        fun getVerificationClient(): VerificationsApi {
                if(apiClient != null)
                {
                        return VerificationsApi(apiClient)
                }
                return VerificationsApi(ApiClient())
        }

        fun getBasePath():String?{
                if(apiClient != null){
                        return apiClient?.getBasePath()
                }
                return "not initialized"
        }
}

==> 0.0.9.tar.gz: android/src/main/java/com/acuant/sampleapp/TruliooVerificationHelper.kt <==
package com.acuant.sampleapp

import com.trulioo.normalizedapi.ApiClient
import com.trulioo.normalizedapi.api.ConnectionApi
import com.trulioo.normalizedapi.api.VerificationsApi

public class TruliooVerificationHelper {
        //Enter Trulioo credentials
        //private val username = "IOTPay_Demo_DocV_API1"
        //private val password = "Iotpay888666!@#\$"
        private val username = ""
        private val password = ""
        private var apiClient:ApiClient? = null

        fun init(){
                apiClient = ApiClient()
                apiClient?.setUsername(username)
                apiClient?.setPassword(password)
                // Set server address
                // GG20
                // apiClient?.setBasePath("https://api.globaldatacompany.com/")
                // GG25
                apiClient?.setBasePath("https://api.globaldatacompany.com/")
                //apiClient?.setBasePath("https://api.globaltest.com/")
        }

        fun getConnectionClient():ConnectionApi{
                if(apiClient != null)
                {
                        return ConnectionApi(apiClient)
                }
                return ConnectionApi(ApiClient())
        }

        fun getVerificationClient(): VerificationsApi {
                if(apiClient != null)
                {
                        return VerificationsApi(apiClient)
                }
                return VerificationsApi(ApiClient())
        }

        fun getBasePath():String?{
                if(apiClient != null){
                        return apiClient?.getBasePath()
                }
                return ""
                //return "not initialized"
        }
}
